@@ -2,7 +2,7 @@
 # -*- coding:utf-8 -*-
 # This Python file uses the following encoding: utf-8
 
-VERSION = (0,5,2)
+VERSION = (0,5,3)
 APPLICATION_NAME = "Dynamic Link"
 VERSION_str = str(VERSION).strip('()').replace(',','.').replace(' ','')
 VERSION_INFO = """
@@ -12,6 +12,10 @@ Modification date: 03.08.2011
 Hints:
 
 
+- 0.5.3     New stable release with updated readme.
+- 0.5.2.2   structure of repository changed - src folder removed so readme is
+            on the toplevel
+- 0.5.2.1   In templates sentences changed.
 - 0.5.2     stable - general django dependences in setup removed
 - 0.5.1     new stable
 - 0.5.0.2   some text in templates changed
